@@ -1,3 +1,4 @@
+#![cfg_attr(docsrs, feature(doc_cfg))]
 //! Syntax aware debug printing.
 //!
 //! Makes use of `syn` and `prettyplease` in order to provide the most
@@ -71,17 +72,13 @@ pub use debug_tuple::DebugTuple;
 pub use debug_tuple_struct::DebugTupleStruct;
 
 #[cfg(feature = "pretty")]
-#[cfg_attr(docsrs, doc(cfg(feature = "pretty")))]
 mod pretty;
 #[cfg(feature = "pretty")]
-#[cfg_attr(docsrs, doc(cfg(feature = "pretty")))]
 pub use pretty::debug;
 
 #[cfg(feature = "colors")]
-#[cfg_attr(docsrs, doc(cfg(feature = "colors")))]
 mod colors;
 #[cfg(feature = "colors")]
-#[cfg_attr(docsrs, doc(cfg(feature = "colors")))]
 pub use colors::color;
 
 #[cfg(feature = "derive")]
@@ -140,7 +137,6 @@ pub trait DebugPls {
     ///
     /// ```
     /// use dbg_pls::{debug, DebugPls, Formatter};
-    /// use std::fmt;
     ///
     /// struct Position {
     ///     longitude: f32,
@@ -173,22 +169,138 @@ impl<'a> Formatter<'a> {
         expr
     }
 
+    /// Writes a wrap expression into the formatter.
+    /// This is typically reserved for more advanced uses
     pub fn write_expr(self, expr: impl Into<syn::Expr>) {
         *self.expr = expr.into();
     }
 
+    /// Creates a [`DebugStruct`] builder designed to assist with creation of
+    /// [`DebugPls`] implementations for structs.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use dbg_pls::{debug, DebugPls, Formatter};
+    ///
+    /// struct Foo {
+    ///     bar: i32,
+    ///     baz: String,
+    /// }
+    ///
+    /// impl DebugPls for Foo {
+    ///     fn fmt(&self, f: Formatter) {
+    ///         f.debug_struct("Foo")
+    ///             .field("bar", &self.bar)
+    ///             .field("baz", &self.baz)
+    ///             .finish()
+    ///     }
+    /// }
+    /// let value = Foo {
+    ///     bar: 10,
+    ///     baz: "Hello World".to_string(),
+    /// };
+    /// assert_eq!(
+    ///     format!("{}", debug(&value)),
+    ///     "Foo { bar: 10, baz: \"Hello World\" }",
+    /// );
+    /// ```
     pub fn debug_struct(self, name: &str) -> DebugStruct<'a> {
         DebugStruct::new(self, name)
     }
+
+    /// Creates a [`DebugTuple`] builder designed to assist with creation of
+    /// [`DebugPls`] implementations for tuples.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use dbg_pls::{debug, DebugPls, Formatter};
+    ///
+    /// struct Foo(i32, String);
+    ///
+    /// impl DebugPls for Foo {
+    ///     fn fmt(&self, f: Formatter) {
+    ///         f.debug_tuple()
+    ///             .field(&self.0)
+    ///             .field(&self.1)
+    ///             .finish()
+    ///     }
+    /// }
+    ///
+    /// let value = Foo(10, "Hello".to_string());
+    /// assert_eq!(format!("{}", debug(&value)), "(10, \"Hello\")");
+    /// ```
     pub fn debug_tuple(self) -> DebugTuple<'a> {
         DebugTuple::new(self)
     }
+
+    /// Creates a [`DebugTupleStruct`] builder designed to assist with creation of
+    /// [`DebugPls`] implementations for tuple structs.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use dbg_pls::{debug, DebugPls, Formatter};
+    ///
+    /// struct Foo(i32, String);
+    ///
+    /// impl DebugPls for Foo {
+    ///     fn fmt(&self, f: Formatter) {
+    ///         f.debug_tuple_struct("Foo")
+    ///             .field(&self.0)
+    ///             .field(&self.1)
+    ///             .finish()
+    ///     }
+    /// }
+    ///
+    /// let value = Foo(10, "Hello".to_string());
+    /// assert_eq!(format!("{}", debug(&value)), "Foo(10, \"Hello\")");
+    /// ```
     pub fn debug_tuple_struct(self, name: &str) -> DebugTupleStruct<'a> {
         DebugTupleStruct::new(self, name)
     }
+
+    /// Creates a [`DebugList`] builder designed to assist with creation of
+    /// [`DebugPls`] implementations for list-like structures.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use dbg_pls::{debug, DebugPls, Formatter};
+    ///
+    /// struct Foo(Vec<i32>);
+    ///
+    /// impl DebugPls for Foo {
+    ///     fn fmt(&self, f: Formatter<'_>) {
+    ///         f.debug_list().entries(&self.0).finish()
+    ///     }
+    /// }
+    ///
+    /// let value = Foo(vec![10, 11]);
+    /// assert_eq!(format!("{}", debug(&value)), "[10, 11]");
+    /// ```
     pub fn debug_list(self) -> DebugList<'a> {
         DebugList::new(self)
     }
+
+    /// Writes an identifier into the formatter. Useful for unit structs/variants
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use dbg_pls::{debug, DebugPls, Formatter};
+    ///
+    /// struct Foo;
+    ///
+    /// impl DebugPls for Foo {
+    ///     fn fmt(&self, f: Formatter<'_>) {
+    ///         f.debug_ident("Foo");
+    ///     }
+    /// }
+    ///
+    /// assert_eq!(format!("{}", debug(&Foo)), "Foo");
+    /// ```
     pub fn debug_ident(self, name: &str) {
         let path: syn::Path = syn::Ident::new(name, Span::call_site()).into();
         self.write_expr(syn::ExprPath {
